@@ -27,16 +27,18 @@ test_that("glmerFormX", {
     ## WARNING: these drop/environment tests are extremely sensitive to environment
     ## they may fail/not fail, or fail differently, within a "testthat" environment vs.
     ##   when run interactively
-    ## AICvec <- c(77.0516381151634, 75.0819116367084, 75.1915023640827)
     expect_that(m_data.3 <- glmer( modStr , data=d, family="binomial"), is_a("glmerMod"))
     expect_that(m_data.4 <- glmer( "x ~ y + z + (1|r)" , data=d, family="binomial"), is_a("glmerMod"))
-    ## interactively:
+    ## interactively: (interactive() is TRUE {i.e. doesn't behave as I would expect} within testing environment ...
+    ## if (interactive()) {
+    ## AICvec <- c(77.0516381151634, 75.0819116367084, 75.1915023640827)
     ## expect_equal(drop1(m_data.3)$AIC,AICvec)
     ## expect_equal(drop1(m_data.4)$AIC,AICvec)
-    ## in test environment:
-    expect_error(drop1(m_data.3),data_RE)
-    expect_error(drop1(m_data.4),data_RE)
-
+    ## } else {
+        ## in test environment [NOT test_
+        expect_error(drop1(m_data.3),data_RE)
+        expect_error(drop1(m_data.4),data_RE)
+    ##}
 })
 
 test_that("glmerForm", {
@@ -202,18 +204,22 @@ test_that("lapply etc.", {
     expect_is(lapply(listOfFormulas,glmer,family=binomial,data=cbpp),"list")
 })
 
+test_that("formula and data validation work with do.call() in artificial environment", {
+    ## This ensures compatibility of lmer when it's called from the
+    ## C-level Rf_eval() with an environment that doesn't exist on the
+    ## stack (i.e. C implementation in magrittr 2.0)
+    e <- new.env()
+    e$. <- mtcars
+    expect_is(
+        do.call(lme4::lmer, list("disp ~ (1 | cyl)", quote(.)), envir = e),
+        "merMod"
+    )
 
-test_that("missDataFun", {
-    X <- expand.grid(x1=1:10, x2=1:10, x3=1:10, x4=1:10, g=letters[1:20])
-    X$y <- X$x1 + rnorm(10)[X$g] + rnorm(200000)
-    (t1 <- system.time(lmer(y ~ x1 + x2 + x3 + x4 + (1|g), data=X,
-                            control=lmerControl(optimizer=NULL))))
-    g <- function(X) {
-        X$y <- X$x1 + rnorm(10)[X$g] + rnorm(200000)
-        lme4:::missDataFun(X)
+    fn <- function(data) {
+        lme4::lmer("disp ~ (1 | cyl)", data = data)
     }
-    ## should take < 1 second since deparsing is now skipped
-    (t2 <- system.time(g(X)))
-    ## Timing comparisons should be on a *relative* scale.
-    expect_lte(t2[["elapsed"]], 1/4 * t1[["elapsed"]]) # typical ratio: 0.03
+    expect_is(
+        do.call(fn, list(quote(.)), envir = e),
+        "merMod"
+    )
 })
