@@ -1,5 +1,6 @@
 library("lme4")
 library("testthat")
+testLevel <- if (nzchar(s <- Sys.getenv("LME4_TEST_LEVEL"))) as.numeric(s) else 1
 
 set.seed(101)
 dd <- expand.grid(f1 = factor(1:3),
@@ -30,6 +31,7 @@ test_that("ok with Poisson masking", {
     rm(poisson)
 })
 
+if (testLevel>1) {
 context("testing glmer refit")
 
 test_that("glmer refit", {
@@ -92,3 +94,16 @@ test_that("start_vals", {
                    initCtrl=list(theta=getME(g1,"glmer.nb.theta")))
     expect_equal(fixef(g1),fixef(g2),tol=1e-5)
 })
+
+test_that("control arguments", {
+    dd1 <- dd[1:200,]
+    g1 <- glmer.nb(y ~ f1 + (1|g), data=dd1, initCtrl=list(theta=10))
+    expect_is(g1,"merMod")  ## dumb test - just checking for run w/o error
+    suppressWarnings(g1 <- glmer.nb(y ~ f1 + (1|g), data=dd1,
+                                    nb.control=glmerControl(optimizer="bobyqa")))
+    expect_equal(g1@optinfo$optimizer, "bobyqa")
+    suppressWarnings(g1 <- glmer.nb(y ~ f1 + (1|g), data=dd1,
+                                    nb.control=glmerControl(optCtrl=list(maxfun=2))))
+    expect_equal(g1@optinfo$feval,3)
+})
+} ## testLevel>1
